@@ -3,6 +3,9 @@ use Moose;
 use MooseX::StrictConstructor;
 use MooseX::Types::Path::Class;
 use Compress::Zlib qw(uncompress);
+use Data::Stream::Bulk;
+use Data::Stream::Bulk::Array;
+use Data::Stream::Bulk::Path::Class;
 use Git::PurePerl::DirectoryEntry;
 use Git::PurePerl::Object;
 use Git::PurePerl::Object::Blob;
@@ -10,7 +13,7 @@ use Git::PurePerl::Object::Commit;
 use Git::PurePerl::Object::Tree;
 use Git::PurePerl::Pack;
 use Path::Class;
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 has 'directory' =>
     ( is => 'ro', isa => 'Path::Class::Dir', required => 1, coerce => 1 );
@@ -113,6 +116,32 @@ sub create_object {
     }
 }
 
+sub all_sha1s {
+    my $self = shift;
+    my $dir = dir( $self->directory, '.git', 'objects' );
+
+    my $files = Data::Stream::Bulk::Path::Class->new(
+        dir        => $dir,
+        only_files => 1,
+    );
+    my @streams;
+    push @streams, Data::Stream::Bulk::Filter->new(
+        filter => sub {
+            [   map { m{([a-z0-9]{2})/([a-z0-9]{38})}; $1 . $2 }
+                    grep {m{/[a-z0-9]{2}/}} @$_
+            ];
+        },
+        stream => $files,
+    );
+
+    foreach my $pack ( $self->packs ) {
+        push @streams,
+            Data::Stream::Bulk::Array->new( array => [ $pack->all_sha1s ], );
+    }
+
+    return Data::Stream::Bulk::Cat->new( streams => \@streams, );
+}
+
 1;
 
 __END__
